<?php
namespace FiloBlu\ScratchAndQuiz\Controller\Adminhtml\ScratchAndQuizDetails;

use Magento\Backend\App\Action;

class Edit extends \Magento\Backend\App\Action
{
    /**
     * Core registry
     *
     * @var \Magento\Framework\Registry
     */
    protected $_coreRegistry = null;

    /**
     * @var \Magento\Framework\View\Result\PageFactory
     */
    protected $resultPageFactory;

    protected $scratchAndQuizDetails;

    protected $scratchAndQuizDetailsTranslations;

    /**
     * @param Action\Context $context
     * @param \Magento\Framework\View\Result\PageFactory $resultPageFactory
     * @param \Magento\Framework\Registry $registry
     */
    public function __construct(
        Action\Context $context,
        \Magento\Framework\View\Result\PageFactory $resultPageFactory,
        \Magento\Framework\Registry $registry,
        \FiloBlu\ScratchAndQuiz\Model\ScratchAndQuizDetailsFactory $scratchAndQuizDetails,
        \FiloBlu\ScratchAndQuiz\Model\ScratchAndQuizDetailsTranslationsFactory $scratchAndQuizDetailsTranslations
    ) {
        $this->resultPageFactory = $resultPageFactory;
        $this->_coreRegistry = $registry;
        $this->scratchAndQuizDetails = $scratchAndQuizDetails;
        $this->scratchAndQuizDetailsTranslations = $scratchAndQuizDetailsTranslations;
        parent::__construct($context);
    }

    /**
     * {@inheritdoc}
     */
    protected function _isAllowed()
    {
        return $this->_authorization->isAllowed('FiloBlu_ScratchAndQuiz::config');
    }

    /**
     * Init actions
     *
     * @return \Magento\Backend\Model\View\Result\Page
     */
    protected function _initAction()
    {
        // load layout, set active menu and breadcrumbs
        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->resultPageFactory->create();
        $resultPage->setActiveMenu('FiloBlu_ScratchAndQuiz::general_listdetails')
            ->addBreadcrumb(__('ScratchAndQuiz Details'), __('ScratchAndQuiz Details'))
            ->addBreadcrumb(__('Manage ScratchAndQuiz Details'), __('Manage ScratchAndQuiz Details'));
        return $resultPage;
    }

    public function execute()
    {
        $id = $this->getRequest()->getParam('id');

        $storeId = $this->getRequest()->getParam('store',0);

        $model = $this->scratchAndQuizDetails->create();

        $modelTranslations = $this->scratchAndQuizDetailsTranslations->create();

        if ($id) {
            $modelTranslations->loadByParentAndStoreId($id,$storeId);

            $model->load($id);
            if (!$model->getId()) {
                $this->messageManager->addError(__('This scratchandquiz details no longer exists.'));
                /** \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
                $resultRedirect = $this->resultRedirectFactory->create();

                return $resultRedirect->setPath('*/*/');
            }
        }

        $this->_coreRegistry->register('filoblu_scratchandquizdetails', $model);
        $this->_coreRegistry->register('filoblu_scratchandquizdetails_translations', $modelTranslations);

        /** @var \Magento\Backend\Model\View\Result\Page $resultPage */
        $resultPage = $this->_initAction();
        $resultPage->addBreadcrumb(
            $id ? __('Edit ScratchAndQuiz Details') : __('New ScratchAndQuiz Details'),
            $id ? __('Edit ScratchAndQuiz Details') : __('New ScratchAndQuiz Details')
        );
        $resultPage->getConfig()->getTitle()->prepend(__('ScratchAndQuiz details Page'));
        $resultPage->getConfig()->getTitle()
            ->prepend($model->getId() ? $model->getPromocode() : __('New ScratchAndQuiz Details'));

        return $resultPage;
    }
}