<?php

namespace FiloBlu\ScratchAndQuiz\Setup;

use Magento\Framework\Setup\InstallSchemaInterface;
use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;

class InstallSchema implements InstallSchemaInterface
{

    /**
     * {@inheritdoc}
     */
    public function install(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $installer = $setup;
        $installer->startSetup();

        /**
         * Create table 'filoblu_scratchandquiz'
         */
        if (!$installer->tableExists('filoblu_scratchandquiz')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandquiz'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'enabled', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ], 'Enabled'
                )
                ->addColumn(
                    'code', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 20, [
                    'nullable' => false,
                ], 'Code'
                )
                ->addColumn('description', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Description'
                )
                ->addColumn(
                    'bg_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image'
                )
                ->addColumn(
                    'bg_image_mobile', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image Mobile'
                )
                ->addColumn(
                    'bg_video', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Video'
                )
                ->addColumn('custom_style', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Custom Style'
                )

                ->addColumn('right_id', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Right detail id'
                )
                ->addColumn('left_title', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Left title'
                )
                ->addColumn('right_title', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Left title'
                )
                ->addColumn('right_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Right answer display text'
                )
                ->addColumn('wrong_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Wrong answer display text'
                )

                ->setComment('FiloBlu ScratchAndQuiz Table');

            $installer->getConnection()->createTable($table);
        }

        if (!$installer->tableExists('filoblu_scratchandquiz_translations')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandquiz_translations'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'filoblu_scratchandquiz_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false
                    ],
                    'FiloBlu ScratchAndQuiz Id'
                )
                ->addColumn('serialized_values', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [
                        'nullable' => false
                    ], 'Serialized Values'
                )
                ->addColumn(
                    'store_id', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'unsigned' => true
                    ], 'Store ID'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_translations', ['filoblu_scratchandquiz_id']),
                    ['filoblu_scratchandquiz_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_translations', ['store_id']),
                    ['store_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_translations',
                        'filoblu_scratchandquiz_id',
                        'filoblu_scratchandquiz',
                        'id'
                    ),
                    'filoblu_scratchandquiz_id',
                    $setup->getTable('filoblu_scratchandquiz'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_translations',
                        'store_id',
                        'store',
                        'store_id'
                    ),
                    'store_id',
                    $setup->getTable('store'),
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandquiz_translations',
                        [
                            'filoblu_scratchandquiz_id',
                            'store_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandquiz_id',
                        'store_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndQuiz Translations Table');

            $installer->getConnection()->createTable($table);
        }

        /**
         * Create table 'filoblu_scratchandquiz_details'
         */
        if (!$installer->tableExists('filoblu_scratchandquiz_details')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandquiz_details'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'enabled', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ], 'Enabled'
                )
                ->addColumn('short_display_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Short Display Text'
                )
                ->addColumn('long_display_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Long Display Text'
                )
                ->addColumn(
                    'overlay_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'Overlay Image'
                )
                ->addColumn(
                    'bg_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'BG Image'
                )
                ->addColumn(
                    'promocode', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 20, [], 'Promocode'
                )
                ->addColumn(
                    'cta_link', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, 255, [], 'CTA link'
                )
                ->addColumn('out_display_text', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Out Display Text'
                )
                ->addColumn('cursor_size', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Cursor Size'
                )
                ->addColumn('percentage', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Percentage'
                )
                ->addColumn('scratched_image', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [], 'Scratched Image'
                )
                ->setComment('FiloBlu ScratchAndQuiz Table Details');

            $installer->getConnection()->createTable($table);
        }

        if (!$installer->tableExists('filoblu_scratchandquiz_details_translations')) {
            $table = $installer->getConnection()->newTable(
                $installer->getTable('filoblu_scratchandquiz_details_translations'))
                ->addColumn('id', \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER, null,
                    [
                        'identity' => true,
                        'nullable' => false,
                        'primary' => true
                    ], 'ID'
                )
                ->addColumn(
                    'filoblu_scratchandquiz_details_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false
                    ],
                    'FiloBlu ScratchAndQuiz Details Id'
                )
                ->addColumn('serialized_values', \Magento\Framework\DB\Ddl\Table::TYPE_TEXT, null,
                    [
                        'nullable' => false
                    ], 'Serialized Values'
                )
                ->addColumn(
                    'store_id', \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT, null,
                    [
                        'nullable' => false,
                        'unsigned' => true
                    ], 'Store ID'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_details_translations', ['filoblu_scratchandquiz_details_id']),
                    ['filoblu_scratchandquiz_details_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_details_translations', ['store_id']),
                    ['store_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_details_translations',
                        'filoblu_scratchandquiz_details_id',
                        'filoblu_scratchandquiz_details',
                        'id'
                    ),
                    'filoblu_scratchandquiz_details_id',
                    $setup->getTable('filoblu_scratchandquiz_details'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_details_translations',
                        'store_id',
                        'store',
                        'store_id'
                    ),
                    'store_id',
                    $setup->getTable('store'),
                    'store_id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandquiz_details_translations',
                        [
                            'filoblu_scratchandquiz_details_id',
                            'store_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandquiz_details_id',
                        'store_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndQuiz Details Translations Table');

            $installer->getConnection()->createTable($table);
        }

        /**
         * Create table 'filoblu_scratchandquiz_relations'
         */
        if (!$setup->tableExists('filoblu_scratchandquiz_relations')) {
            $table = $setup->getConnection()
                ->newTable($setup->getTable('filoblu_scratchandquiz_relations'));
            $table->addColumn(
                'filoblu_scratchandquiz_id',
                \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                null,
                [
                    'nullable' => false,
                    'primary' => true,
                ],
                'FiloBlu ScratchAndQuiz Id'
                )
                ->addColumn(
                    'filoblu_scratchandquiz_details_id',
                    \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                    null,
                    [
                        'nullable' => false,
                        'primary' => true,
                    ],
                    'FiloBlu ScratchAndQuiz Details Id'
                )
                ->addColumn(
                    'position',
                    \Magento\Framework\DB\Ddl\Table::TYPE_SMALLINT,
                    null,
                    [
                        'nullable' => false,
                        'default' => '0'
                    ],
                    'Position'
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_relations', ['filoblu_scratchandquiz_id']),
                    ['filoblu_scratchandquiz_id']
                )
                ->addIndex(
                    $setup->getIdxName('filoblu_scratchandquiz_relations', ['filoblu_scratchandquiz_details_id']),
                    ['filoblu_scratchandquiz_details_id']
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_relations',
                        'filoblu_scratchandquiz_id',
                        'filoblu_scratchandquiz',
                        'id'
                    ),
                    'filoblu_scratchandquiz_id',
                    $setup->getTable('filoblu_scratchandquiz'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addForeignKey(
                    $setup->getFkName(
                        'filoblu_scratchandquiz_relations',
                        'filoblu_scratchandquiz_details_id',
                        'filoblu_scratchandquiz_details',
                        'id'
                    ),
                    'filoblu_scratchandquiz_details_id',
                    $setup->getTable('filoblu_scratchandquiz_details'),
                    'id',
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE,
                    \Magento\Framework\DB\Ddl\Table::ACTION_CASCADE
                )
                ->addIndex(
                    $setup->getIdxName(
                        'filoblu_scratchandquiz_relations',
                        [
                            'filoblu_scratchandquiz_id',
                            'filoblu_scratchandquiz_details_id'
                        ],
                        \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ),
                    [
                        'filoblu_scratchandquiz_id',
                        'filoblu_scratchandquiz_details_id'
                    ],
                    [
                        'type' => \Magento\Framework\DB\Adapter\AdapterInterface::INDEX_TYPE_UNIQUE
                    ]
                )
                ->setComment('FiloBlu ScratchAndQuiz Link Table');
            $setup->getConnection()->createTable($table);
        }

        $installer->endSetup();
    }
}
